\name{COV}
\alias{COV}
\title{Calcola la covarianza non corretta}
\description{
  Questa funzione permette il calcolo della covarianza non corretta.
}
\usage{
COV(x,y)
}
\arguments{
  \item{x}{vettore di dati}
  \item{y}{vettore di dati}
}
\details{
 La funzione \code{cov} di \R effettua il calcolo della varianza campionaria, 
 ovvero divide la codevianza per il numero di dati meno uno. Questa funzione
 invece divide la codevianza per ll numero di dati a disposizione.
}
\seealso{
  \code{\link{cov}}.
}
\examples{
x <- c(1,3,2,4,6,7)
y <- c(7,3,2,1,-1,-3)
cov(x,y)
COV(x,y)
}
\keyword{multivariate}

\eof
\name{E}
\alias{E}
\title{Calcola l'indice di eterogeneita'}
\description{
  Questa funzione permette il calcolo dell'indice di eterogeneita' di Gini.
}
\usage{
E(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\seealso{
  \code{\link{var}}.
}
\examples{
x <- c("A", "A", "B", "A", "C", "A")
E(x)
}
\keyword{univar}

\eof
\name{Markov}
\alias{Markov}
\alias{Markov2}
\title{Simulatore di catene di Markov}
\description{
  Questa funzione simula una catena di Markov a stati finiti.
}
\usage{
Markov(x0, n, x, P)
}
\arguments{
  \item{x0}{stato iniziale}
  \item{n}{lunghezza della traiettoria}
  \item{x}{insieme degli stati}
  \item{P}{matrice di probabilita' di transizione}  
}
\value{
    Una lista contente la traiettoria della catena di Markov:
    \item{X}{valori assunti dalla catena di Markov}
    \item{t}{tempi}
 }
\details{
  La funzione \code{Markov2} e' basata sulla funzione \code{\link{sample}}.
}
\seealso{
  \code{\link{gen.vc},\link{trajectory},\link{lewis}}.
}
\examples{
x <- c("P","S","N")
P <- matrix(c(0.5,0.5,0.25,0.25,0,0.25,0.25,0.5,0.5),3,3)
Markov("S",15,x,P)  -> traj
traj
plot(traj$t,unclass(factor(traj$X)),type="s",axes=FALSE,
 xlab="t",ylab="Che tempo fa'")
axis(1)
axis(2,c(1,2,3),levels(factor(traj$X)))
box()
}
\keyword{distribution}

\eof
\name{Me}
\alias{Me}
\title{Calcola la mediana anche per fenomeni qualitativi}
\description{
  Questa funzione permette il calcolo della mediana anche
  nel caso di fenomeni qualitativi ordinabili.
}
\usage{
Me(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\details{
  La funzione \code{median} di \R contenuta nel pacchetto \code{base}
  funziona solo per dati quantitativi. La funzione \code{Me}
   restituisce un messaggio d'errore se la mediana risulta indeterminata.
}
\seealso{
  \code{\link{median}}.
}
\examples{
x <- factor(c("A", "B", "A", "C", "A"))
Me(x)
}
\keyword{univar}

\eof
\name{Rp}
\alias{Rp}
\title{Calcola l'allocazione ottimale di un portafoglio}
\description{
  Questa funzione permette il calcolo dell'allocazione ottimale
  di due titoli di un portafoglio.
}
\usage{
Rp(x,y,pxy)
}
\arguments{
  \item{x}{rendimenti del primo titolo}
  \item{y}{rendimenti del secondo titolo}
  \item{pxy}{distribuzione doppia dei due titoli}
}
\value{
    Una lista contente media e varianza del rendimento del
    portafoglio:
    \item{a}{quota ottimale da allocare nel primo titolo}
    \item{Rm}{rendimento medio.}
    \item{VR}{varianza del portafolio.}
 }
\details{
  La funzione restituisce rendimento medio e varianza attesa del
  portafoglio allocato in modo ottimo. Restituisce inoltre il 
  valore ottimo di capitale da allocare nel primo titolo.
}
\seealso{
  \code{\link{Rpa}}.
}
\examples{
x <- c(11,9,25,7,-2)/100
y <- c(-3,15,2,20,6)/100
pxy <- matrix(rep(0,25),5,5)
pxy[1,1] <- 0.2
pxy[2,2] <- 0.2
pxy[3,3] <- 0.2
pxy[4,4] <- 0.2
pxy[5,5] <- 0.2
Rp(x,y,pxy)
}
\keyword{distribution}

\eof
\name{Rpa}
\alias{Rpa}
\title{Calcola il rendimento di un portafoglio}
\description{
  Questa funzione permette il calcolo del rendimento atteso di un
  portafoglio di due titoli al variare della quantita' allocata
  nei due titoli.
}
\usage{
Rpa(a,x,y,pxy)
}
\arguments{
  \item{a}{percentuale allocata al primo titolo}
  \item{x}{rendimenti del primo titolo}
  \item{y}{rendimenti del secondo titolo}
  \item{pxy}{distribuzione doppia dei due titoli}
}
\value{
    Una lista contente media e varianza del rendimento del
    portafoglio:
    \item{Rm}{rendimento medio.}
    \item{VR}{varianza del portafolio.}
 }
\details{
  La funzione restituisce rendimento medio e varianza attesa del
  portafoglio.
}
\seealso{
  \code{\link{Rp}}.
}
\examples{
x <- c(11,9,25,7,-2)/100
y <- c(-3,15,2,20,6)/100
pxy <- matrix(rep(0,25),5,5)
pxy[1,1] <- 0.2
pxy[2,2] <- 0.2
pxy[3,3] <- 0.2
pxy[4,4] <- 0.2
pxy[5,5] <- 0.2
Rpa(0.1,x,y,pxy)
Rpa(0.5,x,y,pxy)
}
\keyword{distribution}

\eof
\name{birthday}
\alias{birthday}
\title{Calcola la probabilita' di compleanni coincidenti}
\description{
  Questa funzione risolve il problema del calcolo della probabilita'
  di trovare due persone in un gruppo di \code{n} nate lo stesso
  giorno.
}
\usage{
birthday(n)
}
\arguments{
  \item{n}{numero di persone nel gruppo}
}
\seealso{
  \code{\link{pbirthday}}.
}
\examples{
n <- c(5,10,15,20,21,22,23,24,25,30,50,60,
       70,80,90,100,200,300,365)
for(i in n)
 cat("\n n=",i,"P(A)=",birthday(i))
}
\keyword{distribution}

\eof
\name{bubbleplot}
\alias{bubbleplot}
\title{Disegna un grafico a bolle}
\description{
  Questa funzione disegna un grafico a bolle (bubbleplot) a partire
  da una tabella a doppia entrata.
}
\usage{
bubbleplot(tab, joint = TRUE, magnify = 1, 
           filled = TRUE, main = "bubble plot")
}
\arguments{
  \item{tab}{tabella di contingenza a due vie}
  \item{joint}{valore logico. Se \code{TRUE} disegna la distribuzione di
   frequenza congiunta altrimenti le distribuzione condizionata per riga}  
  \item{magnify}{parametro per il controllo dell'ampiezza delle bolle}
  \item{filled}{valore logico. Se \code{TRUE} riempie di colore le bolle}
  \item{main}{titolo del grafico}     
}
\examples{
x <- c("O","O","S","B","S","O","B","B","S",
   "B","O","B","B","O","S")
y <- c("O","B","B","B","S","S","O","O","B",
   "B","O","S","B","S","B")
x <- ordered(x, levels=c("S","B","O")) 
y <- ordered(y, levels=c("S","B","O")) 
table(x,y)
bubbleplot(table(x,y),main="Musica versus Pittura")
}
\keyword{multivariate}

\eof
\name{chi2}
\alias{chi2}
\title{Calcola l'indice di connessione}
\description{
  Questa funzione permette il calcolo dell'indice di connessione.
}
\usage{
chi2(x,y)
}
\arguments{
  \item{x}{vettore di dati}
  \item{y}{vettore di dati}
}
\examples{
x <- rbinom(8,5,0.5)
y <- c("A", "A", "B", "A", "B", "B", "C", "B")
chi2(x,y)
}
\keyword{multivariate}

\eof
\name{cv}
\alias{cv}
\title{Calcola il coefficiente di variazione}
\description{
  Questa funzione permette il calcolo del coefficiente di variazione.
}
\usage{
cv(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\examples{
x <- c(1,3,2,4,6,7)
cv(x)
}
\keyword{univar}

\eof
\name{eta}
\alias{eta}
\title{Calcola l'indice di dipendenza in media}
\description{
  Questa funzione permette il calcolo dell'indice di dipendenza in media e
  traccia il grafico della funzione di regressione.
}
\usage{
eta(x,y)
}
\arguments{
  \item{x}{vettore di dati eventualmente qualitativo}
  \item{y}{vettore di dati numerico}  
}
\details{
  Questa funzione considera la dipendenza in media di \code{y} da \code{x}.
}
\examples{
x <- c(rep(1,10),rep(0,23), rep(2,15))
y <- c(rnorm(10,mean=7),rnorm(23,mean=19),rnorm(15,mean=17))
eta(x,y)
y <- c(rnorm(10,mean=8),rnorm(23,mean=7),rnorm(15,mean=6.5))
eta(x,y)
}
\keyword{multivariate}

\eof
\name{gen.vc}
\alias{gen.vc}
\title{Simula una variabile casuale discreta}
\description{
  Questa funzione permette di simulare un valore da una variabile
  casuale discreta con distribuzione di probabilita' assegnata.
}
\usage{
gen.vc(x,p)
}
\arguments{
  \item{x}{valori assumibili dalla variabile casuale}
  \item{p}{distribuzione di probabilita'}
}
\details{
  La funzione restituisce un numero casuale.
}
\examples{
x <- c(-2,3,7,10,12)
p <- c(0.2, 0.1, 0.4, 0.2, 0.1) 
y <- NULL
for(i in 1:1000) y <- c(y,gen.vc(x,p))
table(y)/length(y)
}
\keyword{distribution}

\eof
\name{gini}
\alias{gini}
\title{Calcola l'indice di concetrazione}
\description{
  Questa funzione permette il calcolo l'indice di concentrazione 
  e il rapporto di concentrazione di Gini. Inoltre disegna la curva
  di Lorenz.
}
\usage{
gini(x, plot=TRUE, add=FALSE, col="black")
}
\arguments{
  \item{x}{vettore di dati}
  \item{plot}{valore logico. Se \code{TRUE} disegna la curva di Lorenz}
  \item{add}{valore logico. Se \code{TRUE} disegna una nuova curva di Lorenz
   sul precedente grafico della curva di concentrazione}
  \item{col}{colore con cui disegnare l'area di concentrazione}  
}
\examples{
x <- c(1,3,4,30,100)
gini(x)
y <- c(10,10,10,10)
gini(y, add=TRUE,col="red")
}
\keyword{univar}

\eof
\name{gioco1}
\alias{gioco1}
\alias{gioco1a}
\title{Simula la scommessa di De Mere}
\description{
  Questa funzione simula la scommessa di de Mere calcolando
  la probabilita' di fare almeno un 6 in 4 lanci di un dado
  regolare.
}
\usage{
gioco1(prove=10000)
gioco1a(prove=10000)
}
\arguments{
  \item{prove}{numero di prove da utilizzare nella simulazione}
}
\details{
 La versione \code{gioco1} della funzione non e' efficiente in termini di
 velocita' in quanto vengono impiegati cicli \code{for}. Si noti la 
 differenza in termini di velocita' con la version \code{gioco1a}.
}
\seealso{
  \code{\link{gioco2}}.
}
\examples{
ptm <- proc.time()
gioco1a(10000)
proc.time() - ptm
ptm <- proc.time()
gioco1(10000)
proc.time() - ptm
}
\keyword{distribution}

\eof
\name{gioco2}
\alias{gioco2}
\alias{gioco2a}
\title{Simula la scommessa di De Mere}
\description{
  Questa funzione simula la scommessa di de Mere calcolando
  la probabilita' di fare almeno un doppio 6 in 24 lanci di un dado
  regolare.
}
\usage{
gioco2(prove=10000)
gioco2a(prove=10000)
}
\arguments{
  \item{prove}{numero di prove da utilizzare nella simulazione}
}
\details{
 La versione \code{gioco2} della funzione non e' efficiente in termini di
 velocita' in quanto vengono impiegati cicli \code{for}. Si noti la 
 differenza in termini di velocita' con la version \code{gioco2a}.
}
\seealso{
  \code{\link{gioco1}}.
}
\examples{
ptm <- proc.time()
gioco2a(10000)
proc.time() - ptm
ptm <- proc.time()
gioco2(10000)
proc.time() - ptm
}
\keyword{distribution}

\eof
\name{hist.pf}
\alias{hist.pf}
\title{Disegna il poligono di frequenza}
\description{
  Questa funzione disegna l'istogramma e vi sovrappone il
  corrispondente poligono di frequenza.
}
\usage{
hist.pf(x, br, ...)
}
\arguments{
  \item{x}{vettore di dati}
  \item{br}{numero di intervalli, metodo di scelta degli intervalli o
  vettore di estremi degli intervalli}
  \item{...}{argomenti da passare alla funzione \code{hist}}
}
\details{
  Il parametro \code{br} si comporta esattamente come il parametro
  \code{breaks} della funzione \code{hist}.
}
\seealso{
  \code{\link{hist}}.
}
\examples{
x <- rnorm(50)
hist.pf(x,br=5)
}
\keyword{univar}

\eof
\name{ic.var}
\alias{ic.var}
\title{Calcola intervallo di confidenza per la varianza}
\description{
  Questa funzione effettua il calcolo dell'intervallo di
  confidenza per la varianza di campione gaussiano.
}
\usage{
ic.var(x, twosides = TRUE, conf.level = 0.95)
}
\arguments{
  \item{x}{vettore di dati}
  \item{twosides}{logico. Se \code{FALSE} l'estremo inferiore e' posto pari a 0}
  \item{conf.level}{livello confidenza}
}
\examples{
x <- c(0.39, 0.68, 0.82, 1.35, 1.38, 1.62, 1.70,
       1.71, 1.85, 2.14, 2.89, 3.69)
ic.var(x)
ic.var(x,FALSE)
}
\keyword{univar}

\eof
\name{interinale}
\title{Dati sul lavoro interinale}
\usage{data(interinale)}
\alias{interinale}
\format{
  Dataset tratti dall'archivio di una societa' interinale
  italiana.
}
\source{Iacus, S.M., Porro, G. (2001)}
\description{
  Si tratta di un campione di dati relativi agli iscritti ed
  avviati alle missioni di una societa' di fornitura di lavoro 
  interinale.
}
\references{
  Iacus, S.M., Porro, G. (2001)  Occupazione interinale e terzo 
  settore. Analisi dei microdati di una societa' ``no profit''  
  di fornitura di lavoro interinale, IRES Quaderno n.2,  
  \emph{IRES-Lombardia}, \url{www.ireslombardia.it}.
}
\examples{
data(interinale)
glm(avviato~., binomial, data=interinale) -> model
model
pr <- predict(model, type="response")
plot(density(pr),xlim=c(0,0.2),main="")
}
\keyword{datasets}

\eof
\name{kurt}
\alias{kurt}
\title{Calcola l'indice di curtosi}
\description{
  Questa funzione permette il calcolo dell'indice di curtosi.
}
\usage{
kurt(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\seealso{
  \code{\link{skew}}.
}
\examples{
x <- rnorm(50)
kurt(x)
y <- rt(50,df=1)
kurt(y)
}
\keyword{univar}

\eof
\name{lewis}
\alias{lewis}
\title{Simulatore di processi di Poisson}
\description{
  Questa funzione simula un processo di Poisson non omogeneo.
}
\usage{
lewis(T, lambda, plot.int = TRUE)
}
\arguments{
  \item{T}{orizzonte temporale}
  \item{lambda}{funzione di intensita'}
  \item{plot.int}{se \code{TRUE} traccia il grafico della funzione di
   intensita' oltre alla traiettoria del processo}
}
\details{
  Disegna una traiettoria di un processo di Poisson non omogeneo
  con funzione di intensita' \code{lambda} (che deve essere una
  funzione di una variabile) nell'intervallo (0,\code{T}).
}
\seealso{
  \code{\link{gen.vc},\link{Markov},\link{trajectory}}.
}
\examples{
lewis(20,sin)
}
\keyword{distribution}

\eof
\name{mean.a}
\alias{mean.a}
\title{Calcola la media armonica}
\description{
  Questa funzione permette il calcolo della media armonica.
}
\usage{
mean.a(x, \dots)
}
\arguments{
  \item{x}{vettore di dati}
  \item{\dots}{parametri aggiuntivi (ignorati in questa versione)}  
}
\seealso{
  \code{\link{mean.g}}.
}
\examples{
x <- c(1,3,2,4,6,7)
mean.a(x)
}
\keyword{univar}

\eof
\name{mean.g}
\alias{mean.g}
\title{Calcola la media geometrica}
\description{
  Questa funzione permette il calcolo della media geometrica.
}
\usage{
mean.g(x,\dots)
}
\arguments{
  \item{x}{vettore di dati}
  \item{\dots}{parametri aggiuntivi (ignorati in questa versione)}  
}
\seealso{
  \code{\link{mean.a}}.
}
\examples{
x <- c(1,3,2,4,6,7)
mean.g(x)
}
\keyword{univar}

\eof
\name{sigma2}
\alias{sigma2}
\title{Calcola la varianza non corretta}
\description{
  Questa funzione calcola la varianza non corretta.
}
\usage{
sigma2(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\details{
  La funzione \code{var} di \R calcola la varianza campionaria corretta, ovvero
  dividendo la devianza per il numero di elementi del campione meno uno. Questa
  funzione calcola la varianza dividendo la stessa quantita' per il numero
  totale di osservazioni.
}
\examples{
x <- rnorm(10)
var(x)
sigma2(x)
}
\keyword{univar}

\eof
\name{skew}
\alias{skew}
\title{Calcola l'indice di asimmetria}
\description{
  Questa funzione permette il calcolo dell'indice di asimmetria.
}
\usage{
skew(x)
}
\arguments{
  \item{x}{vettore di dati}
}
\seealso{
  \code{\link{kurt}}.
}
\examples{
x <- rnorm(50)
skew(x)
y <- rchisq(50,df=1)
skew(y)
}
\keyword{univar}

\eof
\name{test.var}
\alias{test.var}
\title{Calcola intervallo di confidenza per la varianza}
\description{
  Questa funzione effettua il calcolo dell'intervallo di
  confidenza per la varianza di campione gaussiano.
}
\usage{
test.var(x, var0, alternative = c("greater", "less"), alpha = 0.05)
}
\arguments{
  \item{x}{vettore di dati}
  \item{var0}{valore della varianza sotto l'ipotesi nulla}
  \item{alternative}{direzione del test \code{"greater"} o \code{"less"}
  mentre \code{"equal"} non e' ammessa.}
  \item{alpha}{ampiezza del test}
}
\examples{
x <- rnorm(100, sd=5)
var(x)
test.var(x,20)
}
\keyword{univar}

\eof
\name{trajectory}
\alias{trajectory}
\title{Simulatore di processi di diffusione}
\description{
  Questa funzione simula un processo di diffusione.
}
\usage{
trajectory(x0=1,t0=0,T=1,a,b,n=100)
}
\arguments{
  \item{x0}{stato iniziale}
  \item{t0}{istante iniziale}
  \item{T}{istante finale}
  \item{a}{coefficiente di deriva}
  \item{b}{coefficiente di diffusione}
  \item{n}{numero di valori in cui suddividere l'intervallo (\code{t0},\code{T})}    
}
\value{
    Una lista contente la traiettoria del processo di diffusione:
    \item{t}{vettore dei tempi}
    \item{y}{valori assunti dall traiettoria}
 }
\details{
  I due coefficienti di deriva e diffusione devono essere funzioni di due 
  variabili \code{x} e \code{t}. La funzione utilizza lo schema di Eulero
  quindi il processo da simulare deve rispettare le opportune ipotesi sui
  coefficienti dell'equazione differenziale stocastica.
}
\seealso{
  \code{\link{gen.vc},\link{Markov},\link{lewis}}.
}
\examples{
require(ts)
n <- 100
T <- 1
x0 <- 1
mu <- function(x,t) {-x*t}
sigma <- function(x,t) {x*t}
diff <- trajectory(1,0,1,mu,sigma,100)
plot(diff$t,diff$y,type="l")
acf(diff$y, main="Processo di diffusione")
}
\keyword{distribution}

\eof
